//[mahjong-utils](../../../index.md)/[mahjongutils.models.hand](../index.md)/[IRegularHandPattern](index.md)/[anko](anko.md)

# anko

[common]\
open val [anko](anko.md): [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Kotsu](../../mahjongutils.models/-kotsu/index.md)&gt;

暗刻
